@@ -1,33 +1,16 @@
-##################################################################
 package HTML::Merge::Development;
-##################################################################
-# Development.pm - Contains functions for the developmnet        #
-# Author : Eial Solodki                                          #
-# All right reserved - Raz Information Systems Ltd.(c) 1999-2002 #
-# Date : 15/02/2001                                              #
-# Updated :                                                      #
-##################################################################
-
-# Modules ########################################################
 
 use CGI qw/:standard/;
 use HTML::Merge::Error;
 use strict qw(vars subs);
+use warnings;
 require Exporter;
 
-# My Modules #####################################################
-
-use HTML::Merge::Error;
-
-# Globals ########################################################
-
 use vars qw(@ISA @EXPORT $merge_absolute_path $merge_script $extra $file $year);
 
 @ISA = qw(Exporter);
 @EXPORT = qw($merge_absolute_path $merge_script $extra ReadConfig $file $year);
 
-#package HTML::Merge::Development; # bizzare left over ?
-
 $year = (localtime)[5] + 1900;
 
 # Functions ######################################################
@@ -100,8 +83,7 @@ sub Transfer
 {
 	foreach (qw(merge_absolute_path merge_script)) 
 	{
-		print "<INPUT TYPE=HIDDEN NAME=\"$_\" VALUE=\""
-			. param($_) . "\">\n";
+		printf qq(<INPUT TYPE=HIDDEN NAME="%s" VALUE="%s">\n), $_, (param($_)||"");
 	}
 }
 ##################################################################
@@ -112,7 +94,7 @@ sub ReadConfig
 
 	foreach (qw(merge_absolute_path merge_script))
 	{
-		$$_ = param($_);
+		$$_ = param($_) || '';
 		$merge_script =~ s|/.*$||;
 		push(@extra, "$_=$$_");
 	}
@@ -218,14 +200,38 @@ sub WriteConfig
 package HTML::Merge::Ini;
 #####################################################################
 # ini - Contains enviroment vars - the Merge configuration file     #
-# Authors : Roi Illouz & Eial Solodki                               #
 # All right reserved - Raz Information Systems Ltd.(c) 1999-$year   #
-# Date : 21/03/1998                                                 #
+# Date : 14/10/2005                                                 #
 # Last update : $date                               		    #
 # Automatic page  - Generated by the Merge Configuration Web page   #
 #####################################################################
 EOM
 }
-##################################################################
 1;
-##################################################################
+__END__
+
+=head1 NAME
+
+HTML::Merge::Development - Contains functions developer user interface
+
+=head1 DESCRIPTION
+
+This module is used by developers' web based user interface cgi scripts.
+
+
+=head1 COPYRIGHT
+
+Copyright (c) 1999 - 2005 Raz Information Systems Ltd.
+http://www.raz.co.il
+
+This package is distributed under the same terms as Perl itself, see the
+Artistic License on Perl's home page.
+
+=head1 SEE ALSO
+
+perl(1), L<HTML::Merge::Tags>, L<HTML::Merge::Tags>, L<HTML::Merge::Ext>.
+
+
+=cut
+
+
