@@ -15,7 +15,7 @@ use Config;
 use subs qw(quotemeta);
 
 #####################################
-$VERSION = '3.48';
+$VERSION = '3.53';
 #####################################
 # Globals ###########################
 $open = '\$R';
@@ -24,7 +24,7 @@ $open = '\$R';
 
 my @printers = qw(VERSION VAR SQL GET PGET PVAR INDEX PIC STATE CFG INI LOGIN 
 	AUTH DECIDE EMPTY DATE DAY MONTH YEAR DATEDIFF LASTDAY ADDDATE
-	USER MERGE TEMPLATE TRANSFER DUMP NAME TAG COOKIE
+	USER MERGE TEMPLATE TRANSFER DUMP NAME TAG COOKIE SOURCE
 	DATE2UTC UTC2DATE ENV DATEF EVAL HOUR MINUTE SECOND);
 @printers{@printers} = @printers;
 
@@ -285,7 +285,7 @@ sub Do$un$tag
 }
 EOM
 			eval $extend;
-			\$self->Die($@) if $@;
+			$self->Die($@) if $@;
 			$printers{$tag} = ($api eq 'OUT');
 			return $self->WantTag($tag, $inv);
 		}
@@ -363,10 +363,10 @@ sub Line {
 	my $self = shift;
 	my $force = $self->{'force line'};
 	return $force if $force;
-	my $lines = scalar(split(/\n/, $self->{'save'}));
+	my @lines = split(/\n/, $self->{'save'});
 	my $left = substr($self->{'save'}, -length($self->{'source'}));
-	my $ll = scalar(split(/\n/, $left));
-	my $this = $lines - $ll + 1;
+	my @ll = split(/\n/, $left);
+	my $this = @lines - @ll + 1;
 }
 #####################################
 sub Mark {
@@ -396,7 +396,7 @@ sub Die {
 #####################################
 sub Main {
 	my $self = shift;
-	$self->{'source'} =~ s/<(BODY)/<META NAME="GENERATOR" CONTENT="Merge v. $VERSION (c) Raz Information systems www.raz.co.il">\n<$1/i;
+	$self->{'source'} =~ s/<(BODY)/<!-- GENERATOR: "Merge v. $VERSION (c) Raz Information systems www.raz.co.il" -->\n<$1/i;
 	while  ($self->EatOne) {}
 	$self->PrePrint($self->{'source'});
 	$self->{'source'} = '';
@@ -987,7 +987,7 @@ sub DoPEXPORT {
 }
 
 
-*DoREM =&DoEM;
+*DoREM = \&DoEM;
 sub DoEM {}
 
 sub DoTRACE {
@@ -1234,11 +1234,12 @@ sub DoUnCOUNT {
 }
 
 sub DoPIC {
-        my ($self, $engine, $param) = @_;
-	unless ($param =~ s/^\\\.([FRNADX])(.*)$//is) {
+	my ($self, $engine, $param) = @_;
+	my $type;
+	unless ($param =~ s/^\\\.([CFRNADX])(.*)$//is) {
 		$self->Syntax;
 	}
-	my ($type, $param) = (uc($1), $2);
+	($type, $param) = (uc($1), $2);
 	my $code = &UNIVERSAL::can($self, "Picture$type");
 	&$code($self, $param);
 }
@@ -1255,6 +1256,39 @@ sub PictureF {
 EOM
 }
 
+sub PictureC {
+	my ($self, $param) = @_;
+	my @ary;
+	my $flag;
+	$param =~ s/^\\\((.*)\\\)\\\.\\(['"])(.*?)\\\2$/$1\\.\\$2$3\\$2/s;
+	while ($param =~ 
+			s/^\s*\\(['"])(.*?)\\\1\s*\\=\s*\\(['"])(.*?)\\\3\s*//s) {
+		push(@ary, [$2, $4]);
+		if ($param =~ s/^\\\.//) {
+			$flag = 1;
+			last;
+		}
+		unless ($param =~ s/^\\,//) {
+			$self->Syntax;
+		}
+	}
+	$self->Die("Syntax error in PIC.C") unless ($flag);
+	unless ($param =~ s/^\\(["'])(.*?)\\\1$//s) {
+		$self->Syntax;
+	}
+	my $text = $2;
+	my $code = <<EOM;
+"" . (\$__s = "$text",
+EOM
+	foreach (@ary) {
+		my ($from, $to) = @$_;
+		$code .= <<EOM;
+\$__s =~ s/^$from\$/$to/g,
+EOM
+	}
+	$code . ", \$__s)[-1]";
+}
+
 sub PictureR {
 	my ($self, $param) = @_;
 	my @ary;
@@ -1424,10 +1458,10 @@ sub DoMAIL {
 <<EOM;
 	\$__from = "$from";
 	\$__from =~ s/^.*\<(.*)\>\$/\$1/;
-	\$__from =~ s/^(.*?)\s+\(\".*\"\)\$/\$1/;
+	\$__from =~ s/^(.*?)\\s+\(\".*\"\)\$/\$1/;
 	\$__to = "$to";
 	\$__to =~ s/^.*\<(.*)\>\$/\$1/;
-	\$__to =~ s/^(.*?)\s+\(\".*\"\)\$/\$1/;
+	\$__to =~ s/^(.*?)\\s+\(\".*\"\)\$/\$1/;
 	use HTML::Merge::Mail;
 	eval '\$__mail = OpenMail(\$__from, \$__to, \$HTML::Merge::Ini::SMTP_SERVER);';
 
@@ -1933,18 +1967,15 @@ sub DoSOURCE {
 	}
 	$self->Syntax if $param;
 	$self->Push('source', $engine);
-	<<EOM;
-	require HTML::Merge::Development;
-	print '<A HREF="' . 
-	  HTML::Merge::Development::MakeLink('printsource.pl', "template=$file")
-		. '" TITLE="view source">';
-EOM
+	qq!'<A HREF="' . 
+	 HTML::Merge::Development::MakeLink('printsource.pl', "template=$file")
+		. '" TITLE="view source">'!;
 }
 
 sub DoUnSOURCE {
         my ($self, $engine, $param) = @_;
 	$self->Expect($engine, 'source');
-	qq!print "</A>";!;
+	qq!"</A>"!;
 }
 
 sub safecreate {
